package custom.PVPCB;

import java.io.BufferedReader;
import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.OutputStreamWriter;
import java.io.PrintWriter;
import java.net.Socket;
import java.util.ArrayList;
import java.util.List;

import javax.xml.parsers.DocumentBuilderFactory;

import net.l2emuproject.Config;
import net.l2emuproject.gameserver.cache.HtmCache;
import net.l2emuproject.gameserver.communitybbs.CommunityBoard;
import net.l2emuproject.gameserver.communitybbs.IBBSHandler;
import net.l2emuproject.gameserver.communitybbs.Manager.BaseBBSManager;
import net.l2emuproject.gameserver.model.actor.instance.L2PcInstance;

import org.w3c.dom.Document;
import org.w3c.dom.Node;

public class BashOrgBBSManager extends BaseBBSManager implements IBBSHandler
{
	private static String xmlData = Config.DATAPACK_ROOT + "/data/bash.xml";
	private static List<String> quotes = new ArrayList<String>();
	
	@Override
	public String getBoard()
	{
		return "101";
	}

	private static String[] _COMMANDS = { "bash" };

	@Override
	public String[] getCommands()
	{
		return _COMMANDS;
	}

	@Override
	public String handleCommand(L2PcInstance activeChar, String command, String param)
	{
		if(command.equals("bash"))
		{
			showQuote(activeChar, param);
		}
		return null;

	}
	public void showQuote(L2PcInstance player, String param)
	{
		int page = 1;
		int totalPages = quotes.size();

		try
		{
			page = Integer.parseInt(param);
		}
		catch(NumberFormatException e)
		{
			//  
			return;
		}

		if(page > totalPages && page == 1)
		{
			//NotPage
			return;
		}

		if(page > totalPages || page < 1)
		{
			//WrongPage
			return;
		}

		String html = HtmCache.getInstance().getHtm("data/html/CommunityBoard/306.htm");
		html = html.replaceFirst("%quote%", quotes.get(page - 1));
		html = html.replaceFirst("%page%", String.valueOf(page));
		html = html.replaceFirst("%cpage%", String.valueOf(page));
		html = html.replaceFirst("%total_pages%", String.valueOf(totalPages));
		html = html.replaceFirst("%back_page%", String.valueOf(page-1));
		html = html.replaceFirst("%next_page%", String.valueOf(page+1));

		separateAndSend(html, player);
	}
	private static int parseRSS()
	{
		DocumentBuilderFactory factory = DocumentBuilderFactory.newInstance();
		factory.setValidating(false);
		factory.setIgnoringComments(true);
		Document doc = null;
		try
		{
			doc = factory.newDocumentBuilder().parse(new File(xmlData));
		}
		catch(Exception e)
		{
			e.printStackTrace();
		}
		if(doc == null)
			return 0;

		quotes.clear();

		int quotesCounter = 0;
		for(Node n = doc.getFirstChild(); n != null; n = n.getNextSibling())
			if("rss".equalsIgnoreCase(n.getNodeName()))
				for(Node d = n.getFirstChild(); d != null; d = d.getNextSibling())
					if("channel".equalsIgnoreCase(d.getNodeName()))
						for(Node i = d.getFirstChild(); i != null; i = i.getNextSibling())
							if("item".equalsIgnoreCase(i.getNodeName()))
								for(Node z = i.getFirstChild(); z != null; z = z.getNextSibling())
									if("description".equalsIgnoreCase(z.getNodeName()))
									{
										//      $
										quotes.add(z.getTextContent().replaceAll("\\\\", "").replaceAll("\\$", ""));
										quotesCounter++;
									}
		return quotesCounter;
	}
	public static String getPage(String url_server, String url_document)
	{
		StringBuffer buf = new StringBuffer();
		Socket s;
		try
		{
			try
			{
				s = new Socket(url_server, 80);
			}
			catch(Exception e)
			{
				return null;
			}

			s.setSoTimeout(30000); // 30 
			BufferedReader in = new BufferedReader(new InputStreamReader(s.getInputStream(), "Cp1251"));
			PrintWriter out = new PrintWriter(new OutputStreamWriter(s.getOutputStream(), "UTF-8"));

			out.print("GET http://" + url_server + "/" + url_document + " HTTP/1.1\r\n" + //
			"User-Agent: EmuRT Lineage 2 Server\r\n" + //
			"Host: " + url_server + "\r\n" + //
			"Accept: */*\r\n" + //
			"Connection: close\r\n" + //
			"\r\n");
			out.flush();

			boolean header = true;
			for(String line = in.readLine(); line != null; line = in.readLine())
			{
				if(header && line.startsWith("<?xml "))
					header = false;
				if(!header)
					buf.append(line).append("\r\n");
				if(!header && line.startsWith("</rss>"))
					break;
			}

			s.close();
		}
		catch(IOException e)
		{
			e.printStackTrace();
		}
		return buf.toString();
	}

	public static void loadData()
	{
		//       
		String data;
		try
		{
			data = getPage("bash.org.ru", "rss/");
		}
		catch(Exception E)
		{
			data = null;
		}
		if(data == null)
		{
			System.out.println("Service: Bash - RSS data download failed.");
			return;
		}
		data = data.replaceFirst("windows-1251", "utf-8");
		
		writeFile(xmlData, data);

		int parse = parseRSS();
		if(parse == 0)
		{
			System.out.println("Service: Bash - RSS data parse error.");
			return;
		}
		System.out.println("Service: Bash - RSS data parsed: loaded " + parse + " quotes.");
	}
	
	public static void writeFile(String path, String string)
	{
		if(string == null || string.length() == 0)
			return;

		File target = new File(path);

		if(!target.exists())
			try
			{
				target.createNewFile();
			}
			catch(IOException e)
			{
				e.printStackTrace(System.err);
			}

		try
		{
			FileOutputStream fos = new FileOutputStream(target);
			fos.write(string.getBytes("UTF-8"));
			fos.close();
		}
		catch(IOException e)
		{
			e.printStackTrace(System.err);
		}
	}
	public static void main(String[] args)
	{
		loadData();
		CommunityBoard.getInstance().registerBBSHandler(new BashOrgBBSManager());
	}

	public void parsewrite(String ar1, String ar2, String ar3, String ar4, String ar5, L2PcInstance activeChar)
	{}

	public void parsecmd(String command, L2PcInstance activeChar)
	{}
}