//custom_scripts.cfg 
//custom/PVPCB/BuffBBSManager.java 

package custom.PVPCB;

import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.StringTokenizer;

import net.l2emuproject.L2DatabaseFactory;
import net.l2emuproject.gameserver.communitybbs.CommunityBoard;
import net.l2emuproject.gameserver.communitybbs.IBBSHandler;
import net.l2emuproject.gameserver.datatables.SkillTable;
import net.l2emuproject.gameserver.model.L2Effect;
import net.l2emuproject.gameserver.model.L2Skill;
import net.l2emuproject.gameserver.model.actor.instance.L2PcInstance;
import net.l2emuproject.gameserver.model.olympiad.Olympiad;
import net.l2emuproject.gameserver.network.SystemMessageId;

public class BuffBBSManager implements IBBSHandler
{

	@Override
	public String getBoard()
	{
		return "101";
	}

	private static String[] _COMMANDS = { "buffsave", "buffrestore" };

	@Override
	public String[] getCommands()
	{
		return _COMMANDS;
	}

	@Override
	public String handleCommand(L2PcInstance player, String command, String param)
	{
		if(command.equals("buffsave"))
		{
			if(ConfigBBSManager.PVPCB_BUFFER_ALLOW_SAVE_RESTOR)
			{
				SAVE(player);
			}
			else
			{
				player.sendMessage("   !");
				return null;
			}
		}
		if(command.equals("buffrestore"))
		{
			if(ConfigBBSManager.PVPCB_BUFFER_ALLOW_SAVE_RESTOR)
			{
				RESTOR(player);
			}
			else
			{
				player.sendMessage("   !");
				return null;
			}
		}
		return null;
	}

	private void SAVE(L2PcInstance activeChar)
	{
		if(!checkCondition(activeChar))
			return;

		activeChar.reduceAdena("Buff Restore", ConfigBBSManager.PVPCB_BUFFER_PRICE_ONE * ConfigBBSManager.PVPCB_BUFFER_PRICE_MOD_GRP, activeChar, true);

		Connection con = null;
		try
		{
			con = L2DatabaseFactory.getInstance().getConnection();
			PreparedStatement stat = con.prepareStatement("SELECT COUNT(*) FROM community_skillsave WHERE charId=?;");
			stat.setInt(1, activeChar.getObjectId());
			ResultSet rset = stat.executeQuery();
			rset.next();

			String allbuff = "";

			L2Effect skill[] = activeChar.getAllEffects();

			for(int j = 0; j < skill.length; j++)
			{
				allbuff = new StringBuilder().append(allbuff).append(skill[j].getSkill().getId() + ";").toString();
			}

			if(rset.getInt(1) == 0)
			{
				PreparedStatement statement1 = con.prepareStatement("INSERT INTO community_skillsave (charId,skills) values (?,?)");
				statement1.setInt(1, activeChar.getObjectId());
				statement1.setString(2, allbuff);
				statement1.execute();
				statement1.close();
			}
			else
			{
				PreparedStatement statement = con.prepareStatement("UPDATE community_skillsave SET skills=? WHERE charId=?;");
				statement.setString(1, allbuff);
				statement.setInt(2, activeChar.getObjectId());
				statement.execute();
				statement.close();
			}
			rset.close();
			stat.close();
		}
		catch(Exception ignored)
		{
			try
			{
				con.close();
			}
			catch(SQLException e)
			{
				e.printStackTrace();
			}
		}
	}

	private void RESTOR(L2PcInstance activeChar)
	{
		if(!checkCondition(activeChar))
			return;

		activeChar.reduceAdena("Buff Restore", ConfigBBSManager.PVPCB_BUFFER_PRICE_ONE * ConfigBBSManager.PVPCB_BUFFER_PRICE_MOD_GRP, activeChar, true);

		Connection con = null;
		L2Skill skill;
		try
		{
			con = L2DatabaseFactory.getInstance().getConnection();
			PreparedStatement statement = con.prepareStatement("SELECT * FROM community_skillsave WHERE charId=?;");
			statement.setInt(1, activeChar.getObjectId());
			ResultSet rcln = statement.executeQuery();
			rcln.next();

			String allskills = rcln.getString(2);
			StringTokenizer stBuff = new StringTokenizer(allskills, ";");
			while(stBuff.hasMoreTokens())
			{
				int skilltoresatore = Integer.parseInt(stBuff.nextToken());

				int skilllevel = SkillTable.getInstance().getMaxLevel(skilltoresatore);

				skill = SkillTable.getInstance().getInfo(skilltoresatore, skilllevel);

				PreparedStatement st = con.prepareStatement("SELECT COUNT(*) FROM communitybuff WHERE skillID=?;");
				st.setInt(1, skilltoresatore);
				ResultSet rs = st.executeQuery();
				rs.next();

				if(rs.getInt(1) != 0)
				{
					skill.getEffects(activeChar, activeChar);
				}
				else
				{
					activeChar.sendMessage(": " + skill.getName() + " (" + skill.getId() + "),    !");
				}

				rs.close();
				st.close();
			}
			rcln.close();
			statement.close();
		}
		catch(Exception ignored)
		{
			if(con != null)
				try
				{
					con.close();
				}
				catch(SQLException e)
				{
					e.printStackTrace();
				}

		}
	}

	public boolean checkCondition(L2PcInstance player)
	{
		if(player == null){ return false; }
		if(!ConfigBBSManager.PVPCB_BUFFER_ALLOW_SAVE_RESTOR_ABNORMAL)
		{
			if(player.isInCombat())
			{
				player.sendMessage("    .");
				return false;
			}
			if(player.isSitting())
			{
				player.sendMessage("  .");
				return false;
			}
			if(player.isChaotic())
			{
				player.sendMessage("   PK .");
				return false;
			}
			if(player.isInOlympiadMode() || Olympiad.getInstance().isRegistered(player) || player.getOlympiadGameId() != -1)
			{
				player.sendMessage("    .");
				return false;
			}
			if(player.isInFunEvent())
			{
				player.sendMessage("     .");
				return false;
			}
			if(player.isInJail())
			{
				player.sendMessage("    .");
				return false;
			}
			if(player.isInKarteiCube())
			{
				player.sendMessage("    KarteiCube.");
				return false;
			}
			if(player.isInUndergroundColiseum())
			{
				player.sendMessage("    Underground Coliseum.");
				return false;
			}
			if(player.isFlying())
			{
				player.sendMessage("    .");
				return false;
			}
			if(player.getInstanceId() > 0)
			{
				player.sendMessage("   .");
				return false;
			}
		}
		if(player.getLevel() > ConfigBBSManager.PVPCB_BUFFER_MAX_LVL || player.getLevel() < ConfigBBSManager.PVPCB_BUFFER_MIN_LVL)
		{
			player.sendMessage("    !");
			return false;
		}
		if(player.getAdena() < ConfigBBSManager.PVPCB_BUFFER_PRICE_ONE * ConfigBBSManager.PVPCB_BUFFER_PRICE_MOD_GRP)
		{
			player.sendPacket(SystemMessageId.YOU_NOT_ENOUGH_ADENA);
			return false;
		}
		return true;
	}

	public static void main(String[] args)
	{
		CommunityBoard.getInstance().registerBBSHandler(new BuffBBSManager());
	}
}